Name:           blktap
# https://github.com/xapi-project/blktap/issues/100
# https://raw.githubusercontent.com/xapi-project/blktap/master/VERSION
Version:        3.0.0
Release:        4%{?dist}.git0.9.2
Summary:        Blktap Userspace Tools + Library
License:        BSD and LGPLv2+
URL:            http://wiki.xen.org/wiki/Blktap
Source0:        https://github.com/xapi-project/blktap/archive/%{version}.tar.gz#/%{name}-0.9.2.tar.gz
BuildRequires:  automake
BuildRequires:  autoconf
BuildRequires:  e2fsprogs-devel
BuildRequires:  libaio-devel
BuildRequires:  libtool
BuildRequires:  libuuid-devel
BuildRequires:  openssl-devel
BuildRequires:  xen-devel
# only Xen arches
ExclusiveArch:  %{ix86} x86_64 ia64

%description
The blktap userspace toolkit provides a user-level disk I/O
interface. The blktap mechanism involves a kernel driver that acts
similarly to the existing Xen/Linux blkback driver, and a set of
associated user-level libraries.  Using these tools, blktap allows
virtual block devices presented to VMs to be implemented in userspace
and to be backed by raw partitions, files, network, etc.

The key benefit of blktap is that it makes it easy and fast to write
arbitrary block backends, and that these user-level backends actually
perform very well.  Specifically:

- Metadata disk formats such as Copy-on-Write, encrypted disks, sparse
  formats and other compression features can be easily implemented.

- Accessing file-based images from userspace avoids problems related
  to flushing dirty pages which are present in the Linux loopback
  driver.  (Specifically, doing a large number of writes to an
  NFS-backed image don't result in the OOM killer going berserk.)

- Per-disk handler processes enable easier userspace policing of block
  resources, and process-granularity QoS techniques (disk scheduling
  and related tools) may be trivially applied to block devices.

- It's very easy to take advantage of userspace facilities such as
  networking libraries, compression utilities, peer-to-peer
  file-sharing systems and so on to build more complex block backends.

- Crashes are contained -- incremental development/debugging is very
  fast.

The tools mainly help to verify and correct disk corruptions.

%package        devel
Summary:        Development files for %{name}
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description    devel
This package contains libraries and header files for
developing applications that use %{name}.

%prep
%setup -qn %{name}-0.9.2

%build
./autogen.sh
%configure --disable-static
%make_build

%install
%make_install
find %{buildroot} -name '*.la' -delete -print
rm -f %{buildroot}%{_sysconfdir}/logrotate.d/blktap
rm -f %{buildroot}%{_sysconfdir}/cron.daily/blktap-log-cleanup

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%doc CONTRIB MAINTAINERS README*
%license LICENSE
%{_bindir}/vhd-*
%{_sbindir}/lvm-util
%{_sbindir}/part-util
%{_sbindir}/tap-ctl
%{_sbindir}/td-rated
%{_sbindir}/td-util
%{_sbindir}/vhdpartx
%{_libdir}/libvhd.so.*
%{_libdir}/libvhdio-2.0.90.so
%{_libdir}/libblktapctl.so.*
%{_libexecdir}/tapdisk
%{_sysconfdir}/udev/rules.d/blktap.rules

%files devel
%{_includedir}/blktap/
%{_includedir}/vhd/
%{_libdir}/libblktapctl.so
%{_libdir}/libvhd.so
%{_libdir}/libvhdio.so

%changelog
* Fri Jul 31 2015 Christopher Meng <rpm@cicku.me> - 3.0.0-4.git0.9.2
- Fix broken -devel subpkg requires tag detected by dnf

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.0.0-3.git0.9.2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Fri Aug 15 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.0.0-2.git0.9.2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Fri Jul 04 2014 Christopher Meng <rpm@cicku.me> - 3.0.0-1.git0.9.2
- Update to 3.0.0

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.90-9.git20111216.62de90d
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.90-8.git20111216.62de90d
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Wed Feb 13 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.90-7.git20111216.62de90d
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Wed Jul 18 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.90-6.git20111216.62de90d
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Sat Jan 28 2012 Dan Horák <dan[at]danny.cz> - 2.0.90-5.git20111216.62de90d
- set ExclusiveArch to Xen arches

* Thu Jan 12 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.90-4.git20111216.62de90d
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Wed Jan 11 2012 David Nalley <david@gnsa.us> 2.0.90-3.git20111216.62de90d
- added a doc
- removed .la file

* Sat Dec 24 2011 David Nalley <david@gnsa.us> 2.0.90-2.git20111216.62de90d
- fixed license section

* Fri Dec 16 2011 David Nalley <david@gnsa.us> 2.0.90-1.git20111216.62de90d
- Initial Fedora packaging efforts
